@@ -1,4 +1,4 @@
-""" CLI integration. """
+"""CLI integration."""
 import os
 import re
 import sys
@@ -14,6 +14,7 @@ CLEAN_RE = re.compile(r'\s+$', re.M)
 
 
 def get_router(directory, database, verbose=0):
+    """Load and initialize a router."""
     from peewee_migrate import LOGGER
     from peewee_migrate.compat import exec_in
     from peewee_migrate.router import Router
@@ -48,6 +49,7 @@ def get_router(directory, database, verbose=0):
 
 @click.group()
 def cli():
+    """Just a group."""
     pass
 
 
@@ -87,19 +89,19 @@ def create(name, database=None, auto=False, auto_source=False, directory=None, v
 @cli.command()
 @click.argument('name', required=False)
 @click.option('--count',
-              required=False, 
-              default=1, 
-              type=int, 
+              required=False,
+              default=1,
+              type=int,
               help="Number of last migrations to be rolled back."
                    "Ignored in case of non-empty name")
 @click.option('--database', default=None, help="Database connection")
-@click.option('--directory', 
-              default='migrations', 
+@click.option('--directory',
+              default='migrations',
               help="Directory where migrations are stored")
 @click.option('-v', '--verbose', count=True)
 def rollback(name, count, database=None, directory=None, verbose=None):
     """
-    Rollback a migration with given name or number of last migrations 
+    Rollback a migration with given name or number of last migrations
     with given --count option as integer number
     """
     router = get_router(directory, database, verbose)
@@ -114,7 +116,7 @@ def rollback(name, count, database=None, directory=None, verbose=None):
             router.rollback(name)
     else:
         router.rollback(name)
-        
+
 
 @cli.command()
 @click.option('--database', default=None, help="Database connection")
